import { useControls } from 'leva';
import { useSelectedEventSphere } from '../../../store/store';

interface Path {
    modeluuid: string;
    points: {
        uuid: string;
        position: [number, number, number];
        rotation: [number, number, number];
        events: string;
        triggers: string;
    }[];
    position: [number, number, number];
    rotation: [number, number, number];
}

const EventsControl = ({ simulationPaths, setSimulationPaths }: { simulationPaths: Path[], setSimulationPaths: any }) => {
    const { selectedEventSphere, setSelectedEventSphere } = useSelectedEventSphere();

    const { events, triggers }: any = useControls({
        events: {
            value: selectedEventSphere?.point?.userData?.events || '',
            options: ['Event1', 'Event2', 'Event3'],
            onChange: (newEvent: string) => updatePathData(newEvent, 'events')
        },
        triggers: {
            value: selectedEventSphere?.point?.userData?.triggers || '',
            options: ['None', 'Trigger1', 'Trigger2', 'Trigger3'],
            onChange: (newTrigger: string) => updatePathData(newTrigger, 'triggers')
        },
    });

    function updatePathData(value: string, key: 'events' | 'triggers') {
        if (!selectedEventSphere) return;

        const updatedPaths = simulationPaths.map((path) => 
            path.modeluuid === selectedEventSphere.path.modeluuid
            ? {
                ...path,
                points: path.points.map((point) =>
                point.uuid === selectedEventSphere.point.uuid
                    ? { ...point, [key]: value }
                    : point
                ),
            }
            : path
        );
        console.log('updatedPaths: ', updatedPaths);
        setSimulationPaths(updatedPaths);
    }

    return null;
};

export default EventsControl;
