import { create } from "zustand";

type Side = "top" | "bottom" | "left" | "right";

interface Widget {
  id: string;
  type: string;
  title: string;
  panel: Side;
  data: any;
}

interface SelectedZoneState {
  zoneName: string;
  activeSides: Side[];
  panelOrder: Side[];
  lockedPanels: Side[];
  widgets: Widget[];
}

interface SelectedZoneStore {
  selectedZone: SelectedZoneState;
  setSelectedZone: (zone: Partial<SelectedZoneState> | ((prev: SelectedZoneState) => SelectedZoneState)) => void;
}

export const useSelectedZoneStore = create<SelectedZoneStore>((set) => ({
  selectedZone: {
    zoneName: "Manufacturing unit",
    activeSides: [],
    panelOrder: [],
    lockedPanels: [],
    widgets: [],
  },
  setSelectedZone: (zone) =>
    set((state) => ({
      selectedZone:
        typeof zone === "function"
          ? zone(state.selectedZone) // Handle functional updates
          : { ...state.selectedZone, ...zone }, // Handle partial updates
    })),
}));